DecisionTreeClassifier

Struct DecisionTreeClassifier 

pub struct DecisionTreeClassifier {
    pub max_depth: Option<usize>,
    pub min_samples_split: usize,
    pub min_samples_leaf: usize,
    pub criterion: SplitCriterion,
    pub max_features: Option<MaxFeatures>,
    pub sample_weight: Option<Array1<f64>>,
    pub class_weight: Option<ClassWeight>,
}
Decision tree classifier parameters (unfitted state).

Fields

max_depth: Option<usize>min_samples_split: usizemin_samples_leaf: usizecriterion: SplitCriterionmax_features: Option<MaxFeatures>

Maximum number of features to consider at each split.

sample_weight: Option<Array1<f64>>

Per-sample weights.

class_weight: Option<ClassWeight>

Class weighting strategy.

Implementations

Source

impl DecisionTreeClassifier

pub fn new() -> Self

Create a new DecisionTreeClassifier with sensible defaults.

pub fn with_max_depth(self, max_depth: Option<usize>) -> Self

Set the maximum depth of the tree.

pub fn with_min_samples_split(self, min_samples_split: usize) -> Self

Set the minimum number of samples required to split a node.

pub fn with_min_samples_leaf(self, min_samples_leaf: usize) -> Self

Set the minimum number of samples required in a leaf node.

pub fn with_criterion(self, criterion: SplitCriterion) -> Self

Set the split quality criterion.

pub fn with_max_features(self, max_features: Option<MaxFeatures>) -> Self

Set the maximum number of features to consider at each split.

pub fn with_sample_weight(self, sample_weight: Option<Array1<f64>>) -> Self

Set per-sample weights.

pub fn with_class_weight(self, class_weight: Option<ClassWeight>) -> Self

Set class weighting strategy.